package edu.mermet.tp8;
import java.awt.event.KeyEvent;


import javax.swing.Action;
import javax.swing.JDesktopPane;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.SwingUtilities;

import edu.mermet.tp8.actions.ActionAfficherBoutons;
import edu.mermet.tp8.actions.ActionAfficherConversion;
import edu.mermet.tp8.actions.ActionAfficherDiaporama;
import edu.mermet.tp8.actions.ActionAfficherTexte;
import edu.mermet.tp8.actions.ActionQuitter;
import edu.mermet.tp8.actions.ActionCommentFaire;
import edu.mermet.tp8.actions.ActionConfigMenu;
import edu.mermet.tp8.fenetres.AbstractFenetreInterne;
import edu.mermet.tp8.fenetres.FenetreBoutons;
import edu.mermet.tp8.fenetres.FenetreConversion;
import edu.mermet.tp8.fenetres.FenetreDiaporama;
import edu.mermet.tp8.fenetres.FenetreSuggestion;
import edu.mermet.tp8.fenetres.FenetreTexte;
import edu.mermet.tp8.preferences.Preference;
import edu.mermet.tp8.dialogues.DialogueCommentFaire;
import edu.mermet.tp8.dialogues.DialogueConfigMenu;

/**
 *
 * @author brunomermet
 */
public class Application extends JFrame {
	private AbstractFenetreInterne conversion;
	private AbstractFenetreInterne texte;
	private AbstractFenetreInterne diaporama;
	private AbstractFenetreInterne boutons;
	private FenetreSuggestion suggestion;
	private DialogueCommentFaire commentFaire;
	private DialogueConfigMenu   configMenu;
	private Action actionQuitter;
	private Action actionAfficherConversion;
	private Action actionAfficherTexte;
	private Action actionAfficherDiaporama;
	private Action actionAfficherBoutons;
	private Action actionCommentFaire;
	private Action actionConfigMenu;

	private JMenu menuFichier;
	private JMenu menuApplications;
	private JMenu menuAide;

	private JMenuItem itemConversion;
	private JMenuItem itemTexte;
	private JMenuItem itemDiaporama;
	private JMenuItem itemBoutons;



	public Application(){
		this.setContentPane(new JDesktopPane());
		setTitle("Multi-Window");
		// ****** Fenetre de suggestion
		suggestion = new FenetreSuggestion();
		suggestion.setVisible(true);
		// ****** Barre de menu ******
		JMenuBar barre = new JMenuBar();
		// ------ menu Fichier ------
		menuFichier = new JMenu("Fichier");
		menuFichier.setMnemonic(KeyEvent.VK_F);
		actionQuitter = new ActionQuitter(this);
		JMenuItem quitter = new JMenuItem(actionQuitter);
		menuFichier.add(quitter);
		barre.add(menuFichier);
		this.setJMenuBar(barre);
		// ------ menu Applications ------
		menuApplications = new JMenu("Applications");
		menuApplications.setMnemonic(KeyEvent.VK_A);

		actionAfficherConversion = new ActionAfficherConversion(this);
		itemConversion = new JMenuItem(actionAfficherConversion);
		menuApplications.add(itemConversion);

		actionAfficherTexte = new ActionAfficherTexte(this);
		itemTexte = new JMenuItem(actionAfficherTexte);
		menuApplications.add(itemTexte);

		actionAfficherDiaporama = new ActionAfficherDiaporama(this);
		itemDiaporama = new JMenuItem(actionAfficherDiaporama);
		menuApplications.add(itemDiaporama);

		actionAfficherBoutons = new ActionAfficherBoutons(this);
		itemBoutons = new JMenuItem(actionAfficherBoutons);
		menuApplications.add(itemBoutons);
		barre.add(menuApplications);

		// ------ menu Aide ------
		menuAide = new JMenu("Aide");
		actionCommentFaire = new ActionCommentFaire(this);
		JMenuItem itemCommentFaire = new JMenuItem(actionCommentFaire);
		menuAide.add(itemCommentFaire);
		actionConfigMenu = new ActionConfigMenu(this);
		JMenuItem itemConfig = new JMenuItem(actionConfigMenu);
		menuAide.add(itemConfig);
		barre.add(menuAide);

		// ****** Fin barre de menu ******

		// ****** Création des fenêtres ******
		// ------ fenêtre conversion ------
		conversion = new FenetreConversion(this, actionAfficherConversion);
		this.add(conversion);
		// ------ fenêtre texte ------
		texte = new FenetreTexte(this, actionAfficherTexte);
		this.add(texte);
		// ------ fenêtre diaporama ------
		diaporama = new FenetreDiaporama(this, actionAfficherDiaporama);
		this.add(diaporama);
		// ------ fenêtre boutons ------
		boutons = new FenetreBoutons(this,actionAfficherBoutons);
		this.add(boutons);

		// ****** Fin création fenêtres ******

		// ****** Création des dialogue ******
		// ------ dialogue comment faire ------
		commentFaire = new DialogueCommentFaire(this);
		configMenu   = new DialogueConfigMenu(this);
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setSize(600,300);
		this.setLocationRelativeTo(null);
		majButton();
		setVisible(true);
	}


	public void enableConversion(boolean b) {
		actionAfficherConversion.setEnabled(b);
	}

	public void enableTexte(boolean b) {
		actionAfficherTexte.setEnabled(b);
	}

	public void enableDiaporama(boolean b) {
		actionAfficherDiaporama.setEnabled(b);
	}

	public void enableBoutons(boolean b) {
		actionAfficherBoutons.setEnabled(b);
	}

	public Action getActionAfficherConversion() {
		return actionAfficherConversion;
	}

	public Action getActionAfficherTexte() {
		return actionAfficherTexte;
	}

	public Action getActionAfficherDiaporama() {
		return actionAfficherDiaporama;
	}

	public static void main(String[] args) 
	{
		Preference preference;
		if(args.length >=1)
			preference = new Preference(args[0]);
		else
			preference = new Preference("");

		SwingUtilities.invokeLater(Application::new);
	}

	public void afficherBoutons() {
		boutons.setVisible(true);
	}
	public void afficherConversion() {
		conversion.setVisible(true);
	}
	public void afficherDiaporama() {
		diaporama.setVisible(true);
	}

	public void afficherCommentFaire()	
	{
		commentFaire.setVisible(true);
	}

	public void afficherConfigMenu()	
	{
		configMenu.setVisible(true);
	}
	
	public void afficherTexte() {
		texte.setVisible(true);
	}

	public void majButton()
	{
		Preference preference =  Preference.getPreference();

		double competence = Double.parseDouble(preference.getProperty("Compétence"));

		
		if(preference.getProperty("Diaporama").equals("Affiché") || (preference.getProperty("Diaporama").equals("Auto") && competence>=2.0))
			itemDiaporama.setVisible(true);
		else
			itemDiaporama.setVisible(false);

		if(preference.getProperty("Conversion Celsius/Farenheit").equals("Affiché") || (preference.getProperty("Conversion Celsius/Farenheit").equals("Auto") && competence>=4.0))
			itemConversion.setVisible(true);
		else
			itemConversion.setVisible(false);
		
		if(preference.getProperty("Saisie de texte").equals("Affiché") || (preference.getProperty("Saisie de texte").equals("Auto") && competence>=4.0))
			itemTexte.setVisible(true);
		else
			itemTexte.setVisible(false);

		if(preference.getProperty("Boutons").equals("Affiché") || (preference.getProperty("Boutons").equals("Auto") && competence>=8.0))
			itemBoutons.setVisible(true);
		else
			itemBoutons.setVisible(false);
	}
}
